contacts.Role (Contact person) — amici1

# `contacts.Role` (Contact person)

Role(id, type, person, company, start_date, end_date)

Master tables : contacts.Roles (Contact persons)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Function (type) : The function of this person in this organization.

- Person (person) : The person having this role in this organization.

- Organization (company) : The organization where this person has this role.

- Start date (start_date) : When this person started to exercise this function in this organization.

- End date (end_date) : When this person stopped to exercise this function in this organization.

- Name (name_column) : See `lino_xl.lib.contacts.models.Role.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.contacts.models.Role.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.contacts.models.Role.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
type | Function | The function of this person in this organization.
person | Person | The person having this role in this organization.
company | Organization | The organization where this person has this role.
start_date | Start date | When this person started to exercise this function in this organization.
end_date | End date | When this person stopped to exercise this function in this organization.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |